Cea608

Enum Cea608 

pub enum Cea608 {
    Text(Text),
    NewMode(Channel, Mode),
    EraseDisplay(Channel),
    EraseNonDisplay(Channel),
    CarriageReturn(Channel),
    Backspace(Channel),
    EndOfCaption(Channel),
    TabOffset(Channel, u8),
    DeleteToEndOfRow(Channel),
    Preamble(Channel, PreambleAddressCode),
    MidRowChange(Channel, MidRow),
}
CEA-608 information

Variants



Text(Text)

Text



NewMode(Channel, Mode)

The channel is changing (or resending) mode



EraseDisplay(Channel)

Erase the currently displayed window contents



EraseNonDisplay(Channel)

Erase the undisplayed window contents



CarriageReturn(Channel)

A carriage return was received



Backspace(Channel)

A backspace was received



EndOfCaption(Channel)

An end of caption was received. In Pop-On mode, swap the undisplayed and displayed window contents



TabOffset(Channel, u8)

Offset the cursor



DeleteToEndOfRow(Channel)

Delete characters from the current cursor position to the end of the row



Preamble(Channel, PreambleAddressCode)

A preamble was received



MidRowChange(Channel, MidRow)

A mid-row was received

Implementations

Source

impl Cea608

pub fn channel(&self) -> Channel

The channel for this parsed CEA-608 data

pub fn into_code(&self, field: Field) -> [Code; 2]

Convert into one or two Code values.